[project]
name = "{{ project_slug }}"
version = "0.1.0"
description = "A Litestar application"
readme = "README.md"
requires-python = ">=3.10"
dependencies = [
    "litestar[standard]>=2.16.0",
    "python-dotenv>=1.1.0",
{% if has_sqlalchemy %}
    "sqlalchemy>=2.0.0",
    "advanced-alchemy>=0.31.0",
{% if database.value == "PostgreSQL" %}
    "psycopg[binary,pool]>=3.3.2",
{% elif database.value == "SQLite" %}
    "aiosqlite>=0.22.1",
{% elif database.value == "MySQL" %}
    "asyncmy>=0.2.10",
{% endif %}
{% endif %}
{% if has_jwt %}
    "pyjwt>=2.10.0",
    "passlib[bcrypt]>=1.7.4",
{% endif %}
]

[project.scripts]
{{ project_slug }} = "app.__main__:main"

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[tool.hatch.build.targets.wheel]
packages = ["app"]

[tool.ruff]
line-length = 120
target-version = "py310"

[tool.ruff.lint]
select = ["E", "F", "I", "UP", "B", "SIM"]
ignore = ["E501"]
